@@ -339,6 +339,16 @@ class Converter:
         if self.output_format == "html_water":
             extension = ".html"
         new_filepath_2 = os.path.join(dirname, f"{bn}{extension}")
+        if do_toc and not output_format.startswith("latex"):
+            with _open(source) as f:
+                cnt = f.read()
+            if self.TOC_MARKER in cnt:
+                bn, ext = os.path.splitext(source)
+                source2_name = bn + f".tmp{random.randint(1000, 5000)}" + ext
+                cnt = cnt.replace(self.TOC_MARKER, self.gen_toc(cnt))
+                with _open(source2_name, "w") as f:
+                    f.write(cnt)
+                source = source2_name
         if self.output_format == "latex" and latex_fix:
             self.latex_lfix_process(
                 bn=bn,
@@ -350,15 +360,6 @@ class Converter:
             )
         elif self.output_format == "html_md":
             html_file = os.path.join(self.tmpd.name, bn + ".html")
-            with _open(source) as f:
-                cnt = f.read()
-            if self.TOC_MARKER in cnt:
-                bn, ext = os.path.splitext(source)
-                source2_name = bn + f".tmp{random.randint(1000, 5000)}" + ext
-                cnt = cnt.replace(self.TOC_MARKER, self.gen_toc(cnt))
-                with _open(source2_name, "w") as f:
-                    f.write(cnt)
-                source = source2_name
             self.convert_file(
                 source=source,
                 output_format="html",
@@ -394,7 +395,7 @@ class Converter:
         elif self.output_format in ("md", "markdown"):
             if bn == orig_bn:
                 bn += ".out"
-            shutil.copy(filepath, new_filepath_2)
+            shutil.copy(source, new_filepath_2)
         else:
             self.convert_file(
                 source=source,
