@@ -10,7 +10,7 @@ from codex_processor.utils import _open, load_config, read_front_matter
 
 class TemplateProcessor:
     re_template = re.compile("{{(?P<template_content>.+?)}}")
-    re_template_file = re.compile("(`|```)(?P<filename>.+?\.(md|docx))(`|```)")
+    re_template_file = re.compile("(`|```)(?P<filename>.+?\\.(md|docx))(`|```)")
     re_variant_start = re.compile("<var:(?P<varname>[a-z0-9_]+)>")
 
     def __init__(
